function getUserInfo() {
    var userInfo = window.CONF?window.CONF:{};
    userInfo.fullPageUrl = window.location.href;
    if(userInfo.fullPageUrl){
        userInfo.url = window.location.href.split('?')[0].substring(26);
    }
    return userInfo;
}

function sendAjaxErrorInfo(error, url, method) {

    var data = {};
    data.errorData = {};
    data.errorData.errorType = "AjaxError";
    data.errorData.url = url;
    data.errorData.msg = method + " " + url + " " + error.status + "(" + error.statusText + ")";
    data.userInfo = getUserInfo();
    data.domain = window.CONF.domain;
    data.errorData.occurtime = new Date().getTime();

    saveErrorData(data);
}

function sendSuperagentErrorInfo(error) {
    var data = {};
    data.errorData = {};
    data.errorData.errorType = "SuperagentError";
    if(error.response && error.response.error){
        data.errorData.url = error.response.error.url;
        data.errorData.msg = error.response.error.message;
        if (!!error.response.error.stack) {
            data.errorData.error = error.response.error.stack.toString();
        }else{
            data.errorData.error = error.response.error;
        }
    }

    data.userInfo = getUserInfo();
    data.domain = window.CONF.domain;
    data.errorData.occurtime = new Date().getTime();

    saveErrorData(data);
}

function sendErrorInfo(error, infoData) {
    var data = infoData;
    if (!data) {
        data = {};
        data.errorData = {};
        data.errorData.errorType = "tryCatchError";
        data.errorData.msg = error.message;
        data.errorData.sendData = error.sendData;
        data.errorData.resultData = error.resultData;
        data.errorData.error = error;
        data.userInfo = getUserInfo();
        data.domain = window.CONF.domain;
    }
    data.errorData.occurtime = new Date().getTime();

    if (!!error && !!error.stack) {
        //如果浏览器有堆栈信息
        //直接使用
        data.errorData.error = error.stack.toString();
    }

    saveErrorData(data);
}

function sendHybridgeError(error){
    var data = {};
    data.errorData = {};
    data.errorData.errorType = "SendHybridgeError";
    if(error){
        data.errorData.msg = error.details + " "+error.error;
        data.errorData.error = error.error;
    }

    data.userInfo = getUserInfo();
    data.domain = window.CONF.domain;
    data.errorData.occurtime = new Date().getTime();

    saveErrorData(data);
}

function saveErrorData(data) {
    $.ajax({
        url: "/monitor/saveErrorData",
        method: "POST",
        data: data,
        dataType: "json"
    }).done(function (data) {
        console.log("/monitor/saveErrorData成功了～～data为：");
        console.log(data);
    }).fail(function (error) {
        console.log("/monitor/saveErrorData失败了～～err为：");
        console.log(error);
    });
}

function savePerformanceData(data) {
    $.ajax({
        url: "/monitor/savePerfData",
        method: "POST",
        data: data,
        dataType: "json"
    }).done(function (data) {
        console.log("/monitor/savePerfData成功了～～data为：");
        console.log(data);
    }).fail(function (error) {
        console.log("/monitor/savePerfData失败了～～err为：");
        console.log(error);
    });
}

function getPerformance (url){
    var performance = window.performance;
    var perfData = {};
    if(!performance){
        perfData.fromPerformance = 0;
    }else{
        perfData.fromPerformance = 1;
        var t = performance.timing;
        //readyTime(准备页面时间)：timing.fetchStart - timing.navigationStart
        perfData.redirectTime = t.redirectEnd - t.redirectStart; //重定向的时间
        perfData.appcacheTime = t.domainLookupStart - t.fetchStart; //检查缓存时间
        perfData.unloadEventTime = t.unloadEventEnd - t.unloadEventStart; //页面卸载时间
        perfData.domainLookupTime = t.domainLookupEnd - t.domainLookupStart; //dns解析时间
        perfData.connectTime = t.connectEnd - t.connectStart; //tcp连接建立时间
        perfData.networkTime = t.connectEnd - t.navigationStart; //网络时间，又称白屏时间??????
        perfData.lookupdomain = t.domainLookupEnd - t.domainLookupStart; //DNS查询耗时
        perfData.responseTime = t.responseEnd - t.requestStart; //资源响应时间 timing.domContentLoadedEventStart ? (timing.responseEnd - timing.responseStart) : -1
        perfData.initDomTreeTime = t.domInteractive - t.responseEnd;//dom树创建完成时间
        perfData.whiteScreenTime = t.responseStart - t.navigationStart; //白屏时间
        perfData.domReadyTime = t.domContentLoadedEventEnd - t.navigationStart; //解析DOM树结构的时间－－用户可操作时间
        perfData.onloadTime = t.loadEventEnd - t.navigationStart; //页面完整加载时间
    }

    var networkData = {};

    var data = {};
    data.url = url;
    //data.pageId = window.DATA.blog.sid;
    
    data.data = {};
    data.data.perfData = perfData;
    data.data.networkData = networkData;
    data.data.userData = getUserInfo();
    data.data.conf = window.CONF;
    data.domain = window.CONF.domain;

    savePerformanceData(data);
}

window.onerror = function (msg, url, line, col, error) {
    setTimeout(function () {
        //不一定所有浏览器都支持col参数
        col = col || (window.event && window.event.errorCharacter) || 0;

        var data = {};
        data.errorData = {};
        data.errorData.errorType = "onError";
        data.errorData.url = url;
        data.errorData.msg = msg;
        data.errorData.line = line;
        data.errorData.col = col;
        data.errorData.error = error;
        data.userInfo = getUserInfo();
        //data.confData = window.CONF;
        data.domain = window.CONF.domain;

        sendErrorInfo(error, data);
    }, 0);

    //return true;
};